==> blanco.plugin.soap_1.0.1-src.zip: blancoSOAPPlugin/src/blanco/plugin/soap/wizards/BlancoSOAPWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.soap.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * EclipsevOC blancoSOAP̂߂̃EBU[hEy[W
 * 
 * @author IGA Tosiki
 */
public class BlancoSOAPWizardPage4 extends WizardPage {

    // private ISelection selection;

    public BlancoSOAPWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoSOAPvOCɊ֘AtH_");
        // this.selection = selection;
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoSOAPvOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/soap ܂)");
        new Label(container, SWT.NONE).setText("    ^`t@CTutH_Ɋi[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE).setText("  4.\[XR[hfBNg");
        new Label(container, SWT.NONE)
                .setText("    WSDL/XSD blanco.wsdl Ɋi[܂B");
        new Label(container, SWT.NONE)
                .setText("    Java blanco/main Ɋi[܂B");
        new Label(container, SWT.NONE)
                .setText("    C#.NET blanco/main Ɋi[܂B");

        setControl(container);
    }
}

==> blanco.plugin.soap_1.0.9-src.zip: blancoSOAPPlugin/src/blanco/plugin/soap/wizards/BlancoSOAPWizardPage4.java <==
/*
 * blanco Framework
 * Copyright (C) 2004-2005 IGA Tosiki
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.soap.wizards;

import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;

/**
 * EclipsevOC blancoSOAP̂߂̃EBU[hEy[W
 * 
 * @author IGA Tosiki
 */
public class BlancoSOAPWizardPage4 extends WizardPage {

    // private ISelection selection;

    public BlancoSOAPWizardPage4(ISelection selection) {
        super("wizardPage");
        setTitle("blancoSOAPvOCɊ֘AtH_");
        // this.selection = selection;
    }

    public void createControl(Composite parent) {
        GridLayout gridLayout = new GridLayout();
        gridLayout.numColumns = 1;

        Composite container = new Composite(parent, SWT.NULL);
        container.setLayout(gridLayout);

        new Label(container, SWT.NONE)
                .setText("blancoSOAPvOCɊ֘AtH_͉L̂ƂłB");
        new Label(container, SWT.NONE).setText("  1.\[XtH_ (tH_ src 𐄏)");
        new Label(container, SWT.NONE)
                .setText("    \[XtH_ݒ(쐬)邱Ƃ܂B");
        new Label(container, SWT.NONE)
                .setText("  2.^fBNg (tH_ meta/soap ܂)");
        new Label(container, SWT.NONE).setText("    ^`t@CTutH_Ɋi[܂B");
        new Label(container, SWT.NONE)
                .setText("  3.e|fBNg (tH_ tmp ƂȂ܂)");
        new Label(container, SWT.NONE).setText("  4.ꂽ\[XR[hi[tH_");
        new Label(container, SWT.NONE).setText("    Eblanco/main (Java)");
        new Label(container, SWT.NONE).setText("    Eblanco.cs/main (C#.NET)");
        new Label(container, SWT.NONE).setText("    Eblanco.wsdl (WSDL/XSD)");

        setControl(container);
    }
}
